# API

``` {toctree}
:maxdepth: 1
:hidden:

data
models
interpretation
visualization
```

<!-- mdformat off(Turn off mdformat to retain grid card syntax.) -->

::::{grid} 1 1 2 3
:gutter: 2

:::{grid-item-card} Data
:link: data
:link-type: doc

Classes and utilities for manipulating genomics data.
:::

:::{grid-item-card} Models
:link: models
:link-type: doc

AlphaGenome client and variant scorers.
:::

:::{grid-item-card} Interpretation
:link: interpretation
:link-type: doc

Sequence interpretation tools (like in silico mutagenesis).
:::

:::{grid-item-card} Visualization
:link: visualization
:link-type: doc

Visualization and plotting tools.
:::

<!-- mdformat on -->
